@@ -8,6 +8,7 @@ import bokeh
 import bokeh.layouts
 import bokeh.palettes
 import dateutil
+import dateutil.parser
 import pandas
 from bokeh.core.properties import Color
 from bokeh.models import DataRange1d, HoverTool, LinearAxis
@@ -262,7 +263,7 @@ class LineGraph:
         tooltip_item = [
             "first_annotation_user_id",
             "first_annotation_username",
-            "first_annotation_started_datetime",
+            "first_annotation_started_date",
             "first_annotation_worktime_hour",
             "annotation_worktime_hour",
             "inspection_worktime_hour",
@@ -482,7 +483,7 @@ class LineGraph:
         tooltip_item = [
             "first_inspection_user_id",
             "first_inspection_username",
-            "first_inspection_started_datetime",
+            "first_inspection_started_date",
             "first_inspection_worktime_hour",
             "inspection_worktime_hour",
             "annotation_count",
@@ -619,7 +620,7 @@ class LineGraph:
         tooltip_item = [
             "first_acceptance_user_id",
             "first_acceptance_username",
-            "first_acceptance_started_datetime",
+            "first_acceptance_started_date",
             "first_acceptance_worktime_hour",
             "acceptance_worktime_hour",
             "annotation_count",
