@@ -68,7 +68,7 @@ class DeleteTask(AbstractCommandLineInterface):
 
         task_status = TaskStatus(task["status"])
         if task_status in [TaskStatus.WORKING, TaskStatus.COMPLETE]:
-            logger.info(f"タスクの状態が作業中/完了状態のため、タスクを削除できません。")
+            logger.info("タスクの状態が作業中/完了状態のため、タスクを削除できません。")
             return False
 
         annotation_list = self.get_annotation_list(project_id, task_id)
@@ -146,7 +146,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "delete"
     subcommand_help = "タスクを削除します。"
     description = "タスクを削除します。ただし、作業中/完了状態のタスクは削除できません。デフォルトは、アノテーションが付与されているタスクは削除できません。"
@@ -154,3 +154,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
+    return parser
