@@ -2,10 +2,12 @@ import argparse
 import copy
 import json
 import logging
+import tempfile
 from pathlib import Path
-from typing import Any, Dict
+from typing import Any, Dict, List, Optional
 
-from annofabapi.models import JobType, ProjectMemberRole
+import pandas
+from annofabapi.models import ProjectJobType, ProjectMemberRole
 
 import annofabcli
 from annofabcli import AnnofabApiFacade
@@ -22,6 +24,9 @@ logger = logging.getLogger(__name__)
 
 DEFAULT_WAIT_OPTIONS = WaitOptions(interval=60, max_tries=360)
 
+TaskInputRelation = Dict[str, List[str]]
+"""task_idとinput_data_idの構造を表現する型"""
+
 
 class PutTask(AbstractCommandLineInterface):
     """
@@ -30,6 +35,10 @@ class PutTask(AbstractCommandLineInterface):
 
     DEFAULT_BY_COUNT = {"allow_duplicate_input_data": False, "input_data_order": "name_asc"}
 
+    TASK_THRESHOLD_FOR_JSON = 10
+    """'--json'が指定されたとき、この値以下ならば`put_task`APIでタスクを登録する。
+    この値を超えているならば、`initiate_tasks_generation`APIでタスクを登録する。"""
+
     def put_task_by_count(self, project_id: str, task_generate_rule: Dict[str, Any]):
         project_last_updated_datetime = self.service.api.get_project(project_id)[0]["updated_datetime"]
         task_generate_rule.update({"_type": "ByCount"})
@@ -68,19 +77,29 @@ class PutTask(AbstractCommandLineInterface):
         logger.info(f"タスクの登録中です（サーバ側の処理）。")
 
         if wait:
-            MAX_WAIT_MINUTUE = wait_options.max_tries * wait_options.interval / 60
-            logger.info(f"最大{MAX_WAIT_MINUTUE}分間、タスク登録処理が終了するまで待ちます。")
+            MAX_WAIT_MINUTE = wait_options.max_tries * wait_options.interval / 60
+            logger.info(f"最大{MAX_WAIT_MINUTE}分間、タスク登録処理が終了するまで待ちます。")
 
             result = self.service.wrapper.wait_for_completion(
                 project_id,
-                job_type=JobType.GEN_TASKS,
+                job_type=ProjectJobType.GEN_TASKS,
                 job_access_interval=wait_options.interval,
                 max_job_access=wait_options.max_tries,
             )
             if result:
                 logger.info(f"タスクの登録が完了しました。")
             else:
-                logger.warning(f"タスクの登録に失敗しました。または、{MAX_WAIT_MINUTUE}分間待っても、タスクの登録が完了しませんでした。")
+                logger.warning(f"タスクの登録に失敗しました。または、{MAX_WAIT_MINUTE}分間待っても、タスクの登録が完了しませんでした。")
+
+    @staticmethod
+    def create_task_relation_dataframe(task_relation_dict: TaskInputRelation) -> pandas.DataFrame:
+        tmp_list = []
+        for task_id, input_data_id_list in task_relation_dict.items():
+            for input_data_id in input_data_id_list:
+                tmp_list.append({"task_id": task_id, "input_data_id": input_data_id})
+        df = pandas.DataFrame(tmp_list)
+        df["input_data_name"] = ""
+        return df[["task_id", "input_data_name", "input_data_id"]]
 
     def main(self):
         args = self.args
@@ -90,6 +109,34 @@ class PutTask(AbstractCommandLineInterface):
         if args.csv is not None:
             csv_file = Path(args.csv)
             self.put_task_from_csv_file(project_id, csv_file)
+        elif args.json is not None:
+            # CSVファイルに変換する
+            task_relation_dict = get_json_from_args(args.json)
+            if len(task_relation_dict) > self.TASK_THRESHOLD_FOR_JSON:
+                df = self.create_task_relation_dataframe(task_relation_dict)
+                with tempfile.NamedTemporaryFile() as f:
+                    df.to_csv(f, index=False, header=None)
+                    self.put_task_from_csv_file(project_id, f.name)
+            else:
+                # 登録件数が少ない場合は、put_taskの方が早いのでこちらで登録する。
+                task_count = 0
+                for task_id, input_data_id_list in task_relation_dict.items():
+                    task = self.service.wrapper.get_task_or_none(project_id, task_id)
+                    if task is None:
+                        logger.debug(f"タスク'{task_id}'を登録します。")
+                        self.service.api.put_task(
+                            project_id, task_id, request_body={"input_data_id_list": input_data_id_list}
+                        )
+                        task_count += 1
+                    else:
+                        logger.warning(f"タスク'{task_id}'はすでに存在するため、登録をスキップします。")
+                        self.service.api.put_task(
+                            project_id, task_id, request_body={"input_data_id_list": input_data_id_list}
+                        )
+
+                logger.info(f"{task_count} 件のタスクを登録しました。")
+                return
+
         elif args.by_count is not None:
             by_count = copy.deepcopy(PutTask.DEFAULT_BY_COUNT)
             by_count.update(get_json_from_args(args.by_count))
@@ -127,6 +174,18 @@ def parse_args(parser: argparse.ArgumentParser):
         ),
     )
 
+    JSON_SAMPLE = '{"task1":["input1","input2"]}'
+    file_group.add_argument(
+        "--json",
+        type=str,
+        help=(
+            "タスクに割り当てる入力データをJSON形式で指定してください。"
+            "keyがtask_id, valueがinput_data_idのlistです。"
+            f"(ex) {JSON_SAMPLE} "
+            "``file://`` を先頭に付けるとjsonファイルを指定できます。"
+        ),
+    )
+
     file_group.add_argument(
         "--by_count",
         type=str,
@@ -143,16 +202,16 @@ def parse_args(parser: argparse.ArgumentParser):
         "--wait_options",
         type=str,
         help="タスクの登録が完了するまで待つ際のオプションを、JSON形式で指定してください。"
-        "`file://`を先頭に付けるとjsonファイルを指定できます。"
-        'デフォルは`{"interval":60, "max_tries":360}` です。'
-        "`interval`:完了したかを問い合わせる間隔[秒], "
-        "`max_tires`:完了したかの問い合わせを最大何回行うか。",
+        " ``file://`` を先頭に付けるとjsonファイルを指定できます。"
+        'デフォルは ``{"interval":60, "max_tries":360}`` です。'
+        "``interval`` :完了したかを問い合わせる間隔[秒], "
+        "``max_tires`` :完了したかの問い合わせを最大何回行うか。",
     )
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "put"
     subcommand_help = "タスクを作成します。"
     description = "タスクを作成します。"
@@ -160,3 +219,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
+    return parser
